@@ -182,7 +182,7 @@ def compile_module(mod, engine=defaultengine):
     return mod
 
 
-def get_main_func(prog: Tuple[Dict[str, Program], Program],
+def get_main_func(prog: Tuple[Tuple[Tuple[str, Program], ...], Program],
                   engine=defaultengine):
     mod_ir = emit_ir(prog[1], dict(prog[0]))
     mod = optimize_ir(mod_ir, opt_level=3)
